// Strict definition to use ES6 classes in node.js
"use strict";

// three.js core and modules from examples
const THREE = require('three');
const OrbitControls = require ('three/examples/jsm/controls/OrbitControls');
const GLTFLoader = require('three/examples/jsm/loaders/GLTFLoader');

// Javascript Image Manipulation Program
const Jimp = require('jimp');

class SpriteSheetBuilder
{
  /**
   * Constructs builder with a single scene containing the GLB object read from
   * the given url and one ambient light of given color and intensity
   * 
   * @param url
   */
  constructor(url, color=0xFFFFFF, intensity=1.0)
  {
    // Creates scene
    this.scene = new THREE.Scene();

    // Creates and adds static ambient light
    this.ambientLight = new THREE.AmbientLight(color, intensity);
    this.scene.add(this.ambientLight);
  }
}



function setup(canvas)
{
/*  // Checks if WebGL is available
  if ( WEBGL.isWebGLAvailable() )
    animate();
  else
    canvas.appendChild( WEBGL.getWebGLErrorMessage() );
    */

  // Scene

  scene = new Scene();

  camera = new PerspectiveCamera( 15, 1, 0.1, 1000 );
  camera.position.z = 15;

  renderer = new WebGLRenderer( { canvas: canvas, alpha: true, preserveDrawingBuffer: true, antialias:true } );

  var light = new AmbientLight( 0xFFFFFF );
  scene.add( light );

  // White directional light at half intensity shining from the top.
  var directionalLight = new DirectionalLight( 0xffffff, 0.5 );
  scene.add( directionalLight );

  var controls = new OrbitControls( camera );
  controls.update();
}


function loadModel(file)
{
  if ( renderer!=undefined)
  {

    var loader = new GLTFLoader();

    loader.load(URL.createObjectURL(file), function(gltf)
      {
        scene.add(gltf.scene);
        model=gltf.scene;
      }, undefined, function(error) {console.error( error );} );

    scene.add(model);
  }
}


function makeImage(f)
{
  document.getElementById('result').innerText=f.name;
  var dataUrl = renderer.domElement.toDataURL("image/png");
  document.getElementById('img').innerText=dataUrl;
}


function animate()
{

	requestAnimationFrame( animate );

  if(controls!=undefined)
    controls.update();

  if(renderer!=undefined)
    renderer.render( scene, camera );
}

//setup(document.getElementById('domino-sprite-sheet-builder-input-canvas'));



